==> vtk6-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkCenteredSliderRepresentation.java <==
// java wrapper for vtkCenteredSliderRepresentation object
//

package vtk;
import vtk.*;

public class vtkCenteredSliderRepresentation extends vtkSliderRepresentation
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long GetPoint1Coordinate_2();
  public vtkCoordinate GetPoint1Coordinate() {
    long temp = GetPoint1Coordinate_2();

    if (temp == 0) return null;
    return (vtkCoordinate)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetPoint2Coordinate_3();
  public vtkCoordinate GetPoint2Coordinate() {
    long temp = GetPoint2Coordinate_3();

    if (temp == 0) return null;
    return (vtkCoordinate)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetTitleText_4(String id0);
  public void SetTitleText(String id0)
    { SetTitleText_4(id0); }

  private native String GetTitleText_5();
  public String GetTitleText()
    { return GetTitleText_5(); }

  private native long GetTubeProperty_6();
  public vtkProperty2D GetTubeProperty() {
    long temp = GetTubeProperty_6();

    if (temp == 0) return null;
    return (vtkProperty2D)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetSliderProperty_7();
  public vtkProperty2D GetSliderProperty() {
    long temp = GetSliderProperty_7();

    if (temp == 0) return null;
    return (vtkProperty2D)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetSelectedProperty_8();
  public vtkProperty2D GetSelectedProperty() {
    long temp = GetSelectedProperty_8();

    if (temp == 0) return null;
    return (vtkProperty2D)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetLabelProperty_9();
  public vtkTextProperty GetLabelProperty() {
    long temp = GetLabelProperty_9();

    if (temp == 0) return null;
    return (vtkTextProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void PlaceWidget_10(double id0[]);
  public void PlaceWidget(double id0[])
    { PlaceWidget_10(id0); }

  private native void BuildRepresentation_11();
  public void BuildRepresentation()
    { BuildRepresentation_11(); }

  private native void StartWidgetInteraction_12(double id0[]);
  public void StartWidgetInteraction(double id0[])
    { StartWidgetInteraction_12(id0); }

  private native int ComputeInteractionState_13(int id0,int id1,int id2);
  public int ComputeInteractionState(int id0,int id1,int id2)
    { return ComputeInteractionState_13(id0,id1,id2); }

  private native void WidgetInteraction_14(double id0[]);
  public void WidgetInteraction(double id0[])
    { WidgetInteraction_14(id0); }

  private native void Highlight_15(int id0);
  public void Highlight(int id0)
    { Highlight_15(id0); }

  private native void GetActors_16(vtkPropCollection id0);
  public void GetActors(vtkPropCollection id0)
    { GetActors_16(id0); }

  private native void ReleaseGraphicsResources_17(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_17(id0); }

  private native int RenderOverlay_18(vtkViewport id0);
  public int RenderOverlay(vtkViewport id0)
    { return RenderOverlay_18(id0); }

  private native int RenderOpaqueGeometry_19(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_19(id0); }

  public vtkCenteredSliderRepresentation() { super(); }

  public vtkCenteredSliderRepresentation(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.0.1-3-aarch64.pkg.tar.xz: vtk/vtkCenteredSliderRepresentation.java <==
// java wrapper for vtkCenteredSliderRepresentation object
//

package vtk;
import vtk.*;

public class vtkCenteredSliderRepresentation extends vtkSliderRepresentation
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long GetPoint1Coordinate_2();
  public vtkCoordinate GetPoint1Coordinate() {
    long temp = GetPoint1Coordinate_2();

    if (temp == 0) return null;
    return (vtkCoordinate)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetPoint2Coordinate_3();
  public vtkCoordinate GetPoint2Coordinate() {
    long temp = GetPoint2Coordinate_3();

    if (temp == 0) return null;
    return (vtkCoordinate)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetTitleText_4(String id0);
  public void SetTitleText(String id0)
    { SetTitleText_4(id0); }

  private native String GetTitleText_5();
  public String GetTitleText()
    { return GetTitleText_5(); }

  private native long GetTubeProperty_6();
  public vtkProperty2D GetTubeProperty() {
    long temp = GetTubeProperty_6();

    if (temp == 0) return null;
    return (vtkProperty2D)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetSliderProperty_7();
  public vtkProperty2D GetSliderProperty() {
    long temp = GetSliderProperty_7();

    if (temp == 0) return null;
    return (vtkProperty2D)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetSelectedProperty_8();
  public vtkProperty2D GetSelectedProperty() {
    long temp = GetSelectedProperty_8();

    if (temp == 0) return null;
    return (vtkProperty2D)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetLabelProperty_9();
  public vtkTextProperty GetLabelProperty() {
    long temp = GetLabelProperty_9();

    if (temp == 0) return null;
    return (vtkTextProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void PlaceWidget_10(double id0[]);
  public void PlaceWidget(double id0[])
    { PlaceWidget_10(id0); }

  private native void BuildRepresentation_11();
  public void BuildRepresentation()
    { BuildRepresentation_11(); }

  private native void StartWidgetInteraction_12(double id0[]);
  public void StartWidgetInteraction(double id0[])
    { StartWidgetInteraction_12(id0); }

  private native int ComputeInteractionState_13(int id0,int id1,int id2);
  public int ComputeInteractionState(int id0,int id1,int id2)
    { return ComputeInteractionState_13(id0,id1,id2); }

  private native void WidgetInteraction_14(double id0[]);
  public void WidgetInteraction(double id0[])
    { WidgetInteraction_14(id0); }

  private native void Highlight_15(int id0);
  public void Highlight(int id0)
    { Highlight_15(id0); }

  private native void GetActors_16(vtkPropCollection id0);
  public void GetActors(vtkPropCollection id0)
    { GetActors_16(id0); }

  private native void ReleaseGraphicsResources_17(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_17(id0); }

  private native int RenderOverlay_18(vtkViewport id0);
  public int RenderOverlay(vtkViewport id0)
    { return RenderOverlay_18(id0); }

  private native int RenderOpaqueGeometry_19(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_19(id0); }

  public vtkCenteredSliderRepresentation() { super(); }

  public vtkCenteredSliderRepresentation(long id) { super(id); }
  public native long   VTKInit();

}
